@@ -421,12 +421,22 @@ FlickrListViewItem::FlickrListViewItem(KIPIPlugins::ImagesListView *view,
                FlickrList::TAGS),
                i18n("Add extra tags per image or use Upload Options tab to "
                     "add tags for all images"));
-    m_tagLineEdit = new KLineEdit(view);
+    //m_tagLineEdit = new KLineEdit(view);
+    //m_tagLineEdit->setToolTip(i18n("Enter extra tags, separated by commas."));
+    //view->setItemWidget(this, static_cast<KIPIPlugins::ImagesListView::ColumnType>(
+    //                    FlickrList::TAGS), m_tagLineEdit);
+    updateItemWidgets();
+}
+
+void FlickrListViewItem::updateItemWidgets()
+{
+    m_tagLineEdit = new KLineEdit(view());
     m_tagLineEdit->setToolTip(i18n("Enter extra tags, separated by commas."));
-    view->setItemWidget(this, static_cast<KIPIPlugins::ImagesListView::ColumnType>(
+    view()->setItemWidget(this, static_cast<KIPIPlugins::ImagesListView::ColumnType>(
                         FlickrList::TAGS), m_tagLineEdit);
 }
 
+
 QStringList FlickrListViewItem::extraTags()
 {
     return m_tagLineEdit->text().split(',', QString::SkipEmptyParts);
