@@ -542,6 +542,8 @@ void GalleryWindow::slotAlbumSelected()
     }
 
     QString albumName = item->text(1);
+
+    // FIXME: This check is not needed? We check for item above already, so this condition here is never reached.
     if (!item)
     {
         d->addPhotoBtn->setEnabled(false);
@@ -748,7 +750,7 @@ void GalleryWindow::slotAddPhotoNext()
         return;
     }
 
-    m_progressDlg->setLabelText( i18n("Uploading file ") +  KUrl(photoPath).fileName() );
+    m_progressDlg->setLabelText( i18n("Uploading file %1", KUrl(photoPath).fileName()) );
 
     if (m_progressDlg->isHidden())
         m_progressDlg->show();
