@@ -27,6 +27,7 @@
 
 #include <QString>
 #include <QImage>
+#include <QMetaType>
 
 // KDE includes
 
@@ -71,4 +72,6 @@ public:
 
 }  // namespace KIPIRawConverterPlugin
 
+Q_DECLARE_METATYPE(KIPIRawConverterPlugin::ActionData)
+
 #endif /* ACTIONS_H */
